==> zio-aws-ec2_2.12-7.21.15.7-sources.jar: zio/aws/ec2/model/CpuOptionsRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CpuOptionsRequest(
    coreCount: Optional[Integer] = Optional.Absent,
    threadsPerCore: Optional[Integer] = Optional.Absent,
    amdSevSnp: Optional[zio.aws.ec2.model.AmdSevSnpSpecification] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.CpuOptionsRequest = {
    import CpuOptionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.CpuOptionsRequest
      .builder()
      .optionallyWith(coreCount.map(value => value: java.lang.Integer))(
        _.coreCount
      )
      .optionallyWith(threadsPerCore.map(value => value: java.lang.Integer))(
        _.threadsPerCore
      )
      .optionallyWith(amdSevSnp.map(value => value.unwrap))(_.amdSevSnp)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.CpuOptionsRequest.ReadOnly =
    zio.aws.ec2.model.CpuOptionsRequest.wrap(buildAwsValue())
}
object CpuOptionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.CpuOptionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.CpuOptionsRequest =
      zio.aws.ec2.model.CpuOptionsRequest(
        coreCount.map(value => value),
        threadsPerCore.map(value => value),
        amdSevSnp.map(value => value)
      )
    def coreCount: Optional[Integer]
    def threadsPerCore: Optional[Integer]
    def amdSevSnp: Optional[zio.aws.ec2.model.AmdSevSnpSpecification]
    def getCoreCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("coreCount", coreCount)
    def getThreadsPerCore: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("threadsPerCore", threadsPerCore)
    def getAmdSevSnp
        : ZIO[Any, AwsError, zio.aws.ec2.model.AmdSevSnpSpecification] =
      AwsError.unwrapOptionField("amdSevSnp", amdSevSnp)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.CpuOptionsRequest
  ) extends zio.aws.ec2.model.CpuOptionsRequest.ReadOnly {
    override val coreCount: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.coreCount())
      .map(value => value: Integer)
    override val threadsPerCore: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.threadsPerCore())
      .map(value => value: Integer)
    override val amdSevSnp: Optional[zio.aws.ec2.model.AmdSevSnpSpecification] =
      zio.aws.core.internal
        .optionalFromNullable(impl.amdSevSnp())
        .map(value => zio.aws.ec2.model.AmdSevSnpSpecification.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.CpuOptionsRequest
  ): zio.aws.ec2.model.CpuOptionsRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.181.1-sources.jar: zio/aws/ec2/model/CpuOptionsRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CpuOptionsRequest(
    coreCount: Optional[Integer] = Optional.Absent,
    threadsPerCore: Optional[Integer] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.CpuOptionsRequest = {
    import CpuOptionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.CpuOptionsRequest
      .builder()
      .optionallyWith(coreCount.map(value => value: java.lang.Integer))(
        _.coreCount
      )
      .optionallyWith(threadsPerCore.map(value => value: java.lang.Integer))(
        _.threadsPerCore
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.CpuOptionsRequest.ReadOnly =
    zio.aws.ec2.model.CpuOptionsRequest.wrap(buildAwsValue())
}
object CpuOptionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.CpuOptionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.CpuOptionsRequest =
      zio.aws.ec2.model.CpuOptionsRequest(
        coreCount.map(value => value),
        threadsPerCore.map(value => value)
      )
    def coreCount: Optional[Integer]
    def threadsPerCore: Optional[Integer]
    def getCoreCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("coreCount", coreCount)
    def getThreadsPerCore: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("threadsPerCore", threadsPerCore)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.CpuOptionsRequest
  ) extends zio.aws.ec2.model.CpuOptionsRequest.ReadOnly {
    override val coreCount: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.coreCount())
      .map(value => value: Integer)
    override val threadsPerCore: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.threadsPerCore())
      .map(value => value: Integer)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.CpuOptionsRequest
  ): zio.aws.ec2.model.CpuOptionsRequest.ReadOnly = new Wrapper(impl)
}
